;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; GNU GENERAL PUBLIC LICENSE ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;MODELO DE COMPETENCIA EN PRECIOS is a model designed for educational purposes as part of
;;Aplicación multiusuario con NetLogo. Modelo de competencia en precios con producto diferenciado.
;;Copyright (C) 2017 Guillermo Badás López

;;This program is free software: you can redistribute it and/or modify
;;it under the terms of the GNU General Public License as published by
;;the Free Software Foundation, either version 3 of the License, or
;;(at your option) any later version.

;;This program is distributed in the hope that it will be useful,
;;but WITHOUT ANY WARRANTY; without even the implied warranty of
;;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;GNU General Public License for more details.

;;You should have received a copy of the GNU General Public License
;;along with this program.  If not, see <https://www.gnu.org/licenses/>.


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; DECLARACIÓN DE LAS VARIABLES ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals
[
  rondas                  ;; Número de rondas transcurridas.
  cantidad-total          ;; Cantidad total en el mercado en función de los precios elegidos por cada usuario.
  precio-total            ;; Suma de todos los precios introducidos por los usuarios.

  lista-color             ;; Lista de colores disponibles para los usuarios.
]

breed [students student]  ;; Nombre asignado al agente.

students-own
[
  user-id                 ;; Identificador único para cada usuario (nombre).
  precio-provisional      ;; Variable auxiliar.
  precio-venta            ;; Precio al cual el usuario vende en el mercado.
  cantidad-venta          ;; Cantidad vendida por cada usuario al mercado para el precio de venta seleccionado por este.
  Ctotal                  ;; Coste total incurrido por el usuario para el precio de venta introducido.
  beneficios              ;; Beneficios obtenidos hasta el momento.
  beneficio-ronda         ;; Beneficio obtenido por cada usuario en la ronda actual.
  enviado?                ;; Variable booleana que indica si el usuario ha seleccionado un precio en la ronda actual.
]



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; FUNCIONES PREPARATORIAS ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to startup
  hubnet-reset

  ;; Gráfico único para cada usuario ;;

  __hubnet-make-plot-narrowcast "Mis precios"
  __hubnet-make-plot-narrowcast "Mis beneficios"
  __hubnet-make-plot-narrowcast "Mercado"
  __hubnet-make-plot-narrowcast "Beneficio"

  ask patches [set pcolor gray]

  crear-lista

end

to crear-lista            ;; Procedimiento para crear la lista de colores que se les asignarán a los usuarios.

  set lista-color (list red orange pink lime sky magenta
                          cyan turquoise green  brown blue
                          red orange pink lime sky magenta
                          cyan turquoise green  brown blue
                          red orange pink lime sky magenta
                          cyan turquoise green  brown blue)

  ;; NOTA: Solamente podrá haber tantos clientes como colores en la lista.         ;;
  ;;       En la lista actual hay 33 colores, suficientes para cualquier actividad ;;

end

to reiniciar              ;; Procedimiento para reiniciar la interfaz del usuario (Llamada botón "Reiniciar").

  set rondas 0
  ask students
  [
    reiniciar-variables
    actualizar-interfaz-clientes
  ]

  borrar-graficos
  enviar

end

to reiniciar-variables    ;; Procedimiento para reiniciar las variables del usuario.

  hubnet-broadcast "precio-al-mercado" 10
  set precio-provisional 0
  set precio-venta 0
  set cantidad-venta 0
  set Ctotal 0
  set beneficios 0
  set beneficio-ronda 0
  set enviado? false
  set label (word user-id ", " precision beneficios 2 ", " precio-venta)

  set cantidad-total 0
  set precio-total 0

end

to borrar-graficos        ;; Procedimiento para borrar todos los gráficos.

  set-current-plot "Mis precios"
  ask students [__hubnet-clear-plot user-id]

  set-current-plot "Mis beneficios"
  ask students [__hubnet-clear-plot user-id]

  set-current-plot "Mercado"
  ask students [__hubnet-clear-plot user-id]

  set-current-plot "Beneficio"
  ask students [__hubnet-clear-plot user-id]

  set-current-plot "Precios"
  ask students [__hubnet-clear-plot user-id]

  set-current-plot "Beneficios"
  ask students [__hubnet-clear-plot user-id]

  clear-all-plots

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; FUNCIONES DE EJECUCIÓN ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to activar                ;; Procedimiento de activación (Llamada botón "Activar").

  every 0.1               ;; Ejecuta cada 0.1 segundos el comando entre corchetes.

  [listen-to-clients]     ;; Obtiene los comandos y datos aportados por los usuarios.


  if auto?                ;; Desarrollo automático de la sesión si dicha funcionalidad está activada. No sería necesario pulsar el botón "Siguiente ronda".
  [
    if not any? students with [enviado? = false]
    and (rondas < num-rondas) [siguiente-ronda]
  ]

end

to siguiente-ronda        ;; Procedimiento que avanza de ronda. (Llamada botón "Siguiente ronda" o procedimiento automático)

  set rondas (rondas + 1 )
  ask students
  [
    realizar-calculos
  ]

  dibujar-graficos

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; CÓDIGO PARA INTERACTUAR CON LOS CLIENTES ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to listen-to-clients

  while [ hubnet-message-waiting? ]
  [
    hubnet-fetch-message

    ifelse hubnet-enter-message?
    [ create-new-student hubnet-message-source ]

    [ ifelse hubnet-exit-message?
      [ remove-student hubnet-message-source ]

      [ execute-command hubnet-message-tag ]
    ]
  ]

end

;; Gestión de la entrada y salida de usuarios ;;

to create-new-student [ id ] ;; Procedimiento de creación de un nuevo usuario.

  let p one-of patches with [ count neighbors = 8 and not any? turtles-here and
                                     not any? neighbors4 with [ any? turtles-here ] ]
  ifelse p = nobody
  [
    user-message "Todos los espacios en esta vista están completos. No se puede agregar más usuarios."
    stop
  ]

  [ create-students 1

    [ set user-id  id
      set shape "person"
      set color  item 0 lista-color
      set lista-color but-first lista-color
      set label-color black
      setxy [pxcor] of p + 0.5 [pycor] of p
      hubnet-send user-id  "Jugador" user-id

        reiniciar-variables
        actualizar-interfaz-clientes
     ]
  ]

end

to remove-student [id]     ;; Procedimiento de eliminación de los usuarios que abandonen la sesión.

  ask students with [user-id = id] [ die ]

end

;; Interpreta cada mensaje de HubNet como un comando ;;

to execute-command [command]

  if command = "precio-al-mercado" ;; Se actualiza la variable precio al mercado cada vez que se ajusta la barra deslizadora.
   [ask students with [user-id = hubnet-message-source]
     [if (enviado? = false)
       [ set precio-provisional hubnet-message ]
     ]
   ]

 if command = "Enviar precio"      ;; Cuando se pulsa el botón "Enviar precio" se envia al mercado el precio seleccionado en la barra.
    [ask students with [user-id = hubnet-message-source]  ;; Solo se puede enviar precios al mercado una vez por ronda.
         [if (enviado? = false)
             [ set precio-venta precio-provisional
               hubnet-send user-id "Precio actual" precision precio-venta 2
               set shape "face happy"
               set enviado? true
             ]
         ]
     ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; PRODCEDIMIENTO PRINCIPAL ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to realizar-calculos      ;; Procedimiento de realización de los cálculos.

  set precio-total  sum [precio-venta] of students
  set cantidad-venta  (Qo - (C1 * precio-venta) + (C2 * (precio-total - precio-venta)))
  set Ctotal (coste-fijo + (A * cantidad-venta) + (B * (cantidad-venta ^ 2)))
  set cantidad-total sum [cantidad-venta] of students

  set beneficio-ronda (precio-venta * cantidad-venta) - Ctotal
  set beneficios beneficios + beneficio-ronda
  set label ( word  user-id ", " precision beneficios 2 ", " precio-venta )
  set enviado? false


  realizar-graficos
  actualizar-interfaz-clientes

end

to actualizar-interfaz-clientes ;; Procedimiento que envia la información actualizada a los usuarios.

  set shape "person"
  hubnet-send user-id "Jugador" user-id
  hubnet-send user-id "Ronda" rondas
  hubnet-send user-id "Beneficios acumulados" precision beneficios 2
  hubnet-send user-id "Beneficios última ronda" precision beneficio-ronda 2
  hubnet-send user-id "Precio actual" precision precio-venta 2
  hubnet-send user-id "Última cantidad" precision cantidad-venta 2
  hubnet-send user-id "Coste de producción" precision Ctotal 2

  enviar

end

to enviar                 ;; Procedimiento que envia la función de costes a los usuarios (Llamada botón "Enviar info" o mediante procedimiento).

  hubnet-broadcast "Función de costes" (word "Ctotal = " coste-fijo " + " A " *Q"  " + "  B  " *Q^2")
  hubnet-broadcast "Función de demanda" (word "Qi = " Qo " - " C1 " *Precio i"  " + "  C2  " *Σ Precio j")

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; CÓDIGO PARA REALIZAR LOS GR�?FICOS ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to realizar-graficos

  ;; Representa los precios enviados por cada jugador en un mismo gráfico ;;

  set-current-plot "Precios"
  create-temporary-plot-pen user-id
  set-plot-pen-color color
  plotxy rondas precio-venta

  ;; Representa los beneficios obtenidos por cada jugador en un mismo gráfico ;;

  set-current-plot "Beneficios"
  create-temporary-plot-pen user-id
  set-plot-pen-color color
  plotxy rondas beneficio-ronda

end

to dibujar-graficos

  set-current-plot "Beneficio"

  ask students[
  let Z 0

  __hubnet-clear-plot user-id

  while [ Z <= 100 ]
    [
       ;; Dibujar el Beneficio

       __hubnet-plotxy user-id Z ((Z * (Qo - (C1 * Z) + (C2 * (precio-total - precio-venta )))) - (coste-fijo + A * (Qo - (C1 * Z) + (C2 * (precio-total - precio-venta ))) + B * ((Qo - (C1 * Z) + (C2 * (precio-total - precio-venta ))) ^ 2)))

       set Z (Z + 1 )
    ]
  ]


  set-current-plot "Mercado"

  ask students [
  let Q 0

  __hubnet-clear-plot user-id

  while [ (Qo - (C1 * Q) + (C2 * (precio-total - precio-venta ))) >= 0 ]
    [
       ;; Dibujar la Demanda

       __hubnet-plotxy user-id (Qo - (C1 * Q) + (C2 * (precio-total - precio-venta))) Q

       set Q (Q + 1 )
    ]
  ]


  ;; Plots específicos para cada cliente ;;

 set-current-plot "Mis precios"
 ask students [__hubnet-plotxy user-id rondas precio-venta]

 set-current-plot "Mis beneficios"
 ask students [__hubnet-plotxy user-id rondas beneficio-ronda]



end


;; The following copyright is included because the coding of some procedures
;; was inspired from models that included this copyright.

; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; The project gratefully acknowllinks the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers
; REC #9814682 and REC-0126227.
;
; Copyright 2005 by Uri Wilensky.  Updated 2005.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2005).  NetLogo.
; http://ccl.northwestern.edu/netlogo/models/PreferentialAttachment.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2005 by Uri Wilensky.  All rights reserved.  See
; http://ccl.northwestern.edu/netlogo/models/PreferentialAttachment
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
861
9
1335
484
-1
-1
42.4
1
12
1
1
1
0
0
0
1
-5
5
-5
5
0
0
1
ticks
30.0

BUTTON
5
10
114
47
Activar
activar
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
5
53
114
91
Enviar Info
enviar
NIL
1
T
TURTLE
NIL
NIL
NIL
NIL
1

BUTTON
119
10
229
48
Reiniciar
reiniciar
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
119
53
230
91
Siguiente ronda
siguiente-ronda
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
336
12
464
45
auto?
auto?
0
1
-1000

SLIDER
281
56
522
89
num-rondas
num-rondas
0
30
15.0
1
1
Rondas
HORIZONTAL

SLIDER
7
172
222
205
Qo
Qo
0
600
70.0
1
1
NIL
HORIZONTAL

SLIDER
7
212
223
245
C1
C1
0
100
20.0
1
1
NIL
HORIZONTAL

SLIDER
7
252
223
285
C2
C2
0
100
50.0
1
1
NIL
HORIZONTAL

SLIDER
9
373
226
406
coste-fijo
coste-fijo
0
50
2.0
1
1
u.m.
HORIZONTAL

SLIDER
9
411
227
444
A
A
0
10
1.0
0.1
1
NIL
HORIZONTAL

SLIDER
9
449
228
482
B
B
0
1
0.0
0.01
1
NIL
HORIZONTAL

MONITOR
588
29
692
74
Ronda
rondas
0
1
11

MONITOR
701
29
818
74
Cantidad total
cantidad-total
2
1
11

TEXTBOX
11
306
237
375
El coste total para cada usuario viene definidio por:\n\nCtotal = CosteFijo + (A*Q) + (B*Q^2)
12
0.0
1

TEXTBOX
9
105
224
167
La demanda obtenida por cada usuario viene definida por:\n\nQi = Qo - C1*Precio i + C2*Σ Precio j
12
0.0
1

PLOT
319
140
479
260
Mis precios
Rondas
Precios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Precios" 1.0 0 -16777216 true "" ""

PLOT
321
181
481
301
Mis beneficios
Rondas
Beneficios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Beneficios" 1.0 0 -16777216 true "" ""

PLOT
587
138
747
258
Mercado
Cantidad
Precio
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Demanda" 1.0 0 -16777216 true "" ""

PLOT
590
177
750
297
Beneficio
Precio
Beneficio
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Beneficio" 1.0 0 -16777216 true "" ""

PLOT
250
107
543
362
Precios
Rondas
Precios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"default" 1.0 0 -16777216 false "" ""

PLOT
554
106
850
361
Beneficios
Rondas
Beneficios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"default" 1.0 0 -16777216 false "" ""

@#$#@#$#@
## ¿QUÉ ES ESTO?

Esta es una actividad diseñada para simular el MODELO DE COMPETENCIA EN PRECIOS CON PRODUCTO DIFERENCIADO.    
Como bien sabemos, en un mercado se puede competir tanto en las cantidades introducidas en este, como en los precios a los que venden el bien. Considerando el precio como una de las variables estategicas más importantes y de mayor valor, entendemos que una parte importante de la competitividad exitente en un mercado, vendrá determinado por este. Adicionalmente, en un mercado no se compite con el mismo producto, sino que, aunque esté dentro del mismo sector, este diferirá uno de otro en particularidades tales como la calidad, prestaciones, durabilidad...  
Por todo esto se introduce el modelo de competencia en precios con producto diferenciado, para observar y ver de que depende la acogida de un producto respecto a otro, que tiene que ver en esto, y sobre todod, que influencia tiene el precio en todo ello.


## ¿CÓMO FUNCIONA?

Los usuarios deciden el precio al que van a vender e introducir su producto en el mercado.    
Cada empresa o vendedor dispone de una misma función de costes de su proceso productivo y de una misma función de demanda.    
Los vendedores deciden el precio al que enviarán su producto y venderán en el mercado. La decisión la tomarán teniendo en cuenta la función de costes y demanda que les ha sido asignada, así como el historico de resultados que han ido obteniendo ronda tras ronda.  
El mercado absorbe toda la oferta de todos los vendedores.    
El beneficio económico para el vendedor es la diferencia entre el precio (cobrado) por cantidad de producto vendido y el coste de producción de este.


## ¿CÓMO USARLO?

INTERFAZ DEL SERVIDOR


Botones

Activar: La función de este botón es arrancar o ejecutar el programa. Este botón es de tipo Forever, es decir, su ejecución es continua, y esta acaba cuando se vuelve a clicar el botón o cuando la ejecución del procedimiento se detiene.

Reiniciar: La misión de este botón es la de situar al programa en el estado inicial, es decir, retornar todas las variables, gráficas y funciones a cero o a su valor por defecto. Su función está destinada para la ejecución de una nueva sesión desde la posición inicial.

Enviar Info: Este botón pretende enviar toda la información referente a la funcione de coste a los participantes. Debe ser pulsado siempre y cuando las condiciones de estas varíen en el transcurso de la sesión. Este botón está referido a los agentes como tal.

Siguiente ronda: Tras ser pulsado, este botón lo que pretende es avanzar de ronda haciendo los cálculos necesarios en función de los valores que tengan los participantes en ese preciso momento. Una vez realizados los cálculos, muestra los resultados obtenidos.

Monitores

Ronda: Este monitor nos ayuda a conocer en que ronda de la sesión nos encontramos, y por consiguiente, las rondas transcurridas durante la experiencia. La ronda avanzará mediante la pulsación del botón “Siguiente ronda�? o mediante un procedimiento automático (siempre y cuando se active) el cual avanza de ronda en el momento en el que todos los usuarios hayan enviado un precio al mercado.

Cantidad total: Este otro monitor nos devuelve la cantidad total ofertada al mercado por parte de las empresas como resultado de la introducción de los diferentes precios elegidos por los usuarios. Es decir, es la cantidad total de bienes o productos ofertados al mercado por parte de todas las empresas competidoras. Esta cantidad está influenciada por los precios elegidos por los usuarios a la hora de introducir un bien al mercado.

Deslizadores

Coste fijo: Ajusta el coste fijo por ronda para los usuarios.

A: Ajusta el factor de costes de los usuarios.

B: Ajusta el factor cuadrático de los costes. 

Coste total = coste-fijo + A * Q + B * Q^2

Qo: Ajusta la costante Qo.

C1: Ajusta la costante C1.

C2: Ajusta la costante C2.

Qi = Q0 – C1*Precioi + C2*Σ Precioj

Gráficos

Precios: Esa gráfica representa y dibuja los precios a los que los usuarios venden u ofertan sus bienes en una determinada ronda. Se caracteriza por tener en una misma gráfica todos los precios tomados o escogidos por todos los participantes ronda tras ronda, para así dar una mejor aproximación o perspectiva de la tendencia tomada y dar una idea de que elección futura será la más conveniente en vista a estos resultados y tendencias.

Beneficios: Esta gráfica tiene una función similar a la anterior, sin embargo en este caso, la variable significativa es la variable beneficio. Por tanto, representa el beneficio obtenido por cada empresa, en cada ronda, en función del precio al que oferta su producto al mercado.


INTERFAZ DEL USUARIO


Botones

Enviar precio: Este botón sirve para enviar el precio al que cada usuario quiere que su empresa venda u oferte los bienes o productos producidos al mercado.

Monitores

Jugador: En este monitor se presenta el nombre de usuario elegido por el participante a la hora de unirse a la sesión. Este es útil ya que a través de este nombre se podrá identificar tanto al usuario en sí, como a sus decisiones durante el transcurso de la experiencia.

Ronda: Este monitor nos informa de la ronda presente en la que se encuentra la sesión o dicho de otro modo, las rondas transcurridas desde el inicio de esta.

Función de demanda: Como su propio nombre indica, nos ofrece y muestra la función de demanda elegida por el administrador y aquella que seguirá el mercado durante la sesión. Esta función es idéntica para todas las empresas.

Función de costes: Nos ofrece la función de costes del proceso productivo elegida por el administrador. Es decir, aquella que gravará el precio elegido por los usuarios y mermará su beneficio. Esta función es idéntica para todas las empresas

Precio actual: En este monitor se muestra el precio que envió el usuario en la presente ronda y en el cual se situarán todos los resultados mostrados.

Última cantidad: Cantidad total ofertada por todas las empresas la ronda anterior a la presente en función de los precios a los que quisieron vender o introducir sus productos al mercado.

Coste de producción: Este monitor muestra el coste de producción incurrido en la ronda anterior en función del precio que se escogió y de la función de costes de producción vigente.

Beneficio última ronda: Se muestran los beneficios obtenidos en la última ronda por parte de la empresa, motivados por el precio propio escogido y el precio escogido por la competencia.

Beneficios acumulados: Este monitor presenta el sumatorio de todos los beneficios propios a lo largo de todas las rondas de la presente sesión.

Deslizadores

Precio-al-mercado: La función de este deslizador es aportar funcionalidad, versatilidad y facilidad a la hora de elegir el precio al que el usuario quiere introducir los bienes producidos por su empresa al mercado.

Gráficas

Mercado: Muestra la función de demanda propiamente dicha. Esta se calcula manteniendo como constantes los valores (precios) introducidos por los competidores en la ronda anterior.

Beneficio: Muestra cual es el beneficio obtenido en función de los precios.Esta se calcula manteniendo como constantes los valores (precios) introducidos por los competidores en la ronda anterior .

Mis precios: En este gráfico se reflejan los precios enviados al mercado por el usuario en las sucesivas rondas.

Mis beneficios: En este gráfico se reflejan los beneficios por ronda obtenidos por el usuario. No refleja lo beneficios acumulados sino los beneficios obtenidos en cada ronda.


## PUESTA EN MARCHA 

1. Abrir la actividad "Modelo de competencia en precios".    
2. Ajustar el ZOOM si es necesario.    
3. Pulsar ACTIVAR.    
4. Pedir a los usuarios que abran el HubNet Client y se conecten a la sesión.    
5. Ajustar los valores de las barras COSTE-FIJO, A, B, Qo, C1 y C2.    
6. Pulsar REINICIAR.    
7. Indicar a los usuarios que realicen su selección del PRECIO y pulsen ENVIAR SELECCIÓN.  
8. Cuando todos hayan realizado su selección (cambian los iconos en la vista 2D) pulsar el boton SIGUIENTE RONDA a no ser que la función auto? esté activada, en cuyo caso la ronda avanzará automaticamente una vez todos los usuarios hayan enviado el precio escogido.    
9. Repetir el punto 7 y 8 tantas veces como se desee.    
10. Al termino de la sesión analizar los resultados con el grupo.


## MODELOS RELACIONADOS

Subasta doble, Tragedy of the Commons HubNet, Oil Cartel, Public Good, Restaurants, Oligopolios

## CREDITOS Y REFERENCIAS

Este modelo ha sido creado por Guillermo Badás López (2017) 

NetLogo credits    
Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
MONITOR
31
24
194
73
Jugador
NIL
3
1

MONITOR
199
24
268
73
Ronda
NIL
3
1

MONITOR
31
137
268
186
Función de costes
NIL
3
1

MONITOR
310
25
415
74
Precio actual
NIL
3
1

SLIDER
32
193
266
226
precio-al-mercado
precio-al-mercado
0.0
100.0
0
1.0
1
€
HORIZONTAL

BUTTON
92
234
192
267
Enviar precio
NIL
NIL
1
T
OBSERVER
NIL
NIL

MONITOR
420
25
529
74
Última cantidad
NIL
3
1

MONITOR
311
79
529
128
Coste de producción
NIL
3
1

MONITOR
312
136
529
185
Beneficios última ronda
NIL
3
1

MONITOR
312
194
529
243
Beneficios acumulados
NIL
3
1

PLOT
9
285
275
528
Mercado
Cantidad
Precio
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Demanda" 1.0 0 -16777216 true "" ""

PLOT
285
285
552
529
Beneficio
Precio
Beneficio
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Beneficio" 1.0 0 -16777216 true "" ""

VIEW
288
540
883
725
0
0
0
1
1
1
1
1
0
1
1
1
-5
5
-5
5

MONITOR
31
80
268
129
Función de demanda
NIL
3
1

PLOT
567
285
878
530
Mis precios
Rondas
Precios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Precios" 1.0 0 -16777216 true "" ""

PLOT
888
284
1211
531
Mis beneficios
Rondas
Beneficios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Beneficios" 1.0 0 -16777216 true "" ""

PLOT
566
24
878
270
Precios
Rondas
Precios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"default" 1.0 0 -16777216 false "" ""

PLOT
889
24
1209
270
Beneficios
Rondas
Beneficios
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"default" 1.0 0 -16777216 false "" ""

@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
